# Django Tools Services

Simple Django app to manage a company services

## Installation

1. Install with pip install `django-tools-services`.

2. Add `djtools.services` to your INSTALLED_APPS setting like this:
```
INSTALLED_APPS = [
    ...
    'djtools.services',
]
```
